DENOFO Comparator
=================

The DENOFO Comparator is a tool for comparing **denofo** annotation files.
It provides functionality for comparing two ``*.dngf`` annotation files and
generating a comparison report with either similarities or differences.

The comparator can be used via the command-line interface (CLI) or the
graphical user interface (GUI).

Command-line interface (CLI)
----------------------------

.. automodule:: denofo.comparator.comparator_cli
    :members:


Graphical user interface (GUI)
------------------------------

.. automodule:: denofo.comparator.comparator_gui
    :members:


Comparator logic implementation
-------------------------------

.. automodule:: denofo.comparator.compare
    :members:
